ILAssemblyManifest Type
The main module of an assembly is a module plus some manifest information.
Record fields
| Record Field |
Description
|
|
|
|
This is the ID of the algorithm used for the hashes of auxiliary
files in the assembly. These hashes are stored in the
|
|
|
|
|
|
Records whether the entrypoint resides in another module.
|
|
Records the types implemented by this assembly in auxiliary modules.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Instance members
| Instance member |
Description
|
|
|
|
|
F# Compiler Guide