ILAssemblyRef Type
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
|
The fully qualified name of the assembly reference, e.g. mscorlib, Version=1.0.3705 etc.
|
|
CLI says this indicates if the assembly can be retargeted (at runtime) to be from a different publisher.
|
|
|
Static members
| Static member |
Description
|
Full Usage:
ILAssemblyRef.FromAssemblyName(arg1)
Parameters:
AssemblyName
Returns: ILAssemblyRef
|
|
F# Compiler Guide