ILAttributeNamedArg Type
Named args: values and flags indicating if they are fields or properties.
F# Compiler Guide
string * ILType * bool * ILAttribElem
obj
IStructuralComparable
,
IStructuralEquatable
,
IComparable
,
ITuple
Named args: values and flags indicating if they are fields or properties.