ILDebugImport Type
Defines an opened namespace, type relevant to a code location. Emitted to the PortablePDB format. Note the format supports additional variations on imported things that are not yet emitted in F#.
Defines an opened namespace, type relevant to a code location. Emitted to the PortablePDB format. Note the format supports additional variations on imported things that are not yet emitted in F#.