ILGenericParameterDef Type
Generic parameters. Formal generic parameter declarations may include the bounds, if any, on the generic parameter.
Record fields
| Record Field |
Description
|
|
At most one is the parent type, the others are interface types.
|
|
Do not use this
|
|
Indicates the type parameter allows ref struct, i.e. an anti constraint.
|
|
Indicates the type argument must have a public nullary constructor.
|
|
Indicates the type argument must be a value type, but not Nullable.
|
|
Indicates the type argument must be a reference type.
|
|
Do not use this
|
|
|
|
Variance of type parameters, only applicable to generic parameters for generic interfaces and delegates.
|
Instance members
| Instance member |
Description
|
|
|
F# Compiler Guide