ILMethodDef Type
IL Method definitions.
Constructors
| Constructor |
Description
|
Full Usage:
ILMethodDef(name, attributes, implAttributes, callingConv, parameters, ret, body, isEntryPoint, genericParams, securityDecls, customAttrs)
Parameters:
string
attributes : MethodAttributes
implAttributes : MethodImplAttributes
callingConv : ILCallingConv
parameters : ILParameters
ret : ILReturn
body : InterruptibleLazy<MethodBody>
isEntryPoint : bool
genericParams : ILGenericParameterDefs
securityDecls : ILSecurityDecls
customAttrs : ILAttributes
Returns: ILMethodDef
|
Functional creation of a value, immediate
|
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Some methods are marked "HasSecurity" even if there are no permissions attached, e.g. if they use SuppressUnmanagedCodeSecurityAttribute
|
|
|
|
|
|
|
|
|
|
Indicates a .cctor method.
|
|
Indicates a .ctor method.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
SafeHandle finalizer must be run.
|
|
|
|
|
|
Indicates this is an instance methods that is not virtual.
|
|
|
|
|
|
|
|
Indicates a static method.
|
|
|
|
The method is exported to unmanaged code using COM interop.
|
|
Indicates an instance methods that is virtual or abstract or implements an interface slot.
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
F# Compiler Guide