ILType Type
Union cases
| Union case |
Description
|
|
Array types
|
|
Reference types. Also may be used for parents of members even if for members in value types.
|
|
Managed pointers.
|
|
ILCode pointers.
|
|
Unmanaged pointers. Nb. the type is used by tools and for binding only, not by the verifier.
|
|
Reference a generic arg.
|
|
Unboxed types, including builtin types.
|
Full Usage:
Void
|
Used only in return and pointer types. |
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
F# Compiler Guide