ILTypeRef Type
Type refs, i.e. references to types in some .NET assembly
Instance members
| Instance member |
Description
|
|
The name of the type in the assembly using the '+' notation for nested types.
|
|
|
|
The name of the type in the assembly using the '.' notation for nested types.
|
The name of the type. This also contains the namespace if Enclosing is empty.
|
|
|
|
|
Where is the type, i.e. is it in this module, in another module in this assembly or in another assembly?
|
Static members
| Static member |
Description
|
Full Usage:
ILTypeRef.Create(scope, enclosing, name)
Parameters:
ILScopeRef
enclosing : string list
name : string
Returns: ILTypeRef
|
F# Compiler Guide