ILReaderMetadataSnapshot Type
Used to implement a Binary file over native memory, used by Roslyn integration
F# Compiler Guide
obj * nativeint * int
obj
IStructuralComparable
,
IStructuralEquatable
,
IComparable
,
ITuple
Used to implement a Binary file over native memory, used by Roslyn integration