FSharpParseFileResults Type
Represents the results of parsing an F# file and a set of analysis operations based on the parse tree alone.
Instance members
| Instance member |
Description
|
|
When these files change then the build is invalid
|
|
Get the errors and warnings for the parse
|
|
Name of the file for which this information were created
|
|
Notable parse info for ParameterInfo at a given location
|
|
|
|
Get declared items and the selected item at the specified location
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Indicates if any errors occurred during the parse
|
|
The syntax tree resulting from the parse
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
F# Compiler Guide