FSharpProjectOptions Type
A set of information describing a project or script build configuration.
Record fields
| Record Field |
Description
|
|
When true, the typechecking environment is known a priori to be incomplete, for example when a .fs file is opened outside of a project. In this case, the number of error messages reported is reduced.
|
Timestamp of project/script load, used to differentiate between different instances of a project load. This ensures that a complete reload of the project or script type checking context occurs on project or script unload/reload.
|
|
|
|
|
Additional command line argument options for the project. These can include additional files and references.
|
|
|
|
The command line arguments for the other projects referenced by this project, indexed by the exact text used in the "-r:" reference in FSharpProjectOptions.
|
|
The files in the project
|
|
Unused in this API and should be 'None' when used as user-specified input
|
|
When true, use the reference resolution rules for scripts rather than the rules for compiler.
|
F# Compiler Guide