FSharpSymbolUse Type
Represents the use of an F# symbol from F# source code
Instance members
| Instance member |
Description
|
|
The display context active at the point where the symbol is used. Can be passed to FSharpType.Format and other methods to format items in a way that is suitable for a specific source code location.
|
|
The file name the reference occurs in
|
|
|
|
Indicates if the reference is in an attribute
|
|
Indicates if the reference is either a builder or a custom operation in a computation expression
|
|
Indicates if the reference is a definition for the symbol, either in a signature or implementation
|
|
Indicates if the reference is via the member being implemented in a class or object expression
|
|
Indicates if the reference is in open statement
|
|
Indicates if the reference is in a pattern
|
|
Indicates if the reference is in a syntactic type
|
|
Indicates if the reference is used for example at a call site
|
|
Indicates if the FSharpSymbolUse is declared as private
|
|
Indicates if the FSharpSymbolUse is private to the implementation & signature file. This is true for function and method parameters.
|
|
The range of text representing the reference to the symbol
|
|
The symbol referenced
|
F# Compiler Guide