Logo F# Compiler Guide

ILegacyReferenceResolver Type

Instance members

Instance member Description

this.DotNetFrameworkReferenceAssembliesRootDirectory

Full Usage: this.DotNetFrameworkReferenceAssembliesRootDirectory

Returns: string
Modifiers: abstract

Get the Reference Assemblies directory for the .NET Framework (on Windows) This is added to the default resolution path for design-time compilations.

Returns: string

this.HighestInstalledNetFrameworkVersion

Full Usage: this.HighestInstalledNetFrameworkVersion

Returns: string
Modifiers: abstract

Get the "v4.5.1"-style moniker for the highest installed .NET Framework version. This is the value passed back to Resolve if no explicit "mscorlib" has been given. Note: If an explicit "mscorlib" is given, then --noframework is being used, and the whole ReferenceResolver logic is essentially unused. However in the future an option may be added to allow an explicit specification of a .NET Framework version to use for scripts.

Returns: string

this.Resolve

Full Usage: this.Resolve

Parameters:
Returns: LegacyResolvedFile[]
Modifiers: abstract

Perform assembly resolution on the given references under the given conditions

resolutionEnvironment : LegacyResolutionEnvironment
references : (string * string)[]
targetFrameworkVersion : string
targetFrameworkDirectories : string list
targetProcessorArchitecture : string
fsharpCoreDir : string
explicitIncludeDirs : string list
implicitIncludeDir : string
logMessage : string -> unit
logDiagnostic : bool -> string -> string -> unit
Returns: LegacyResolvedFile[]

Type something to start searching.