obj
IEquatable<FSharpProjectIdentifier>
IStructuralEquatable
IComparable<FSharpProjectIdentifier>
IComparable
IStructuralComparable
An identifier of an F# project. This serves to identify the same project as it changes over time and enables us to clear obsolete data from caches.
FSharpProjectIdentifier(projectFileName, outputFileName)
string
this.OutputFileName
this.ProjectFileName
Type something to start searching.