ProjectConfig Type
All required information for compiling a project except the source files and referenced projects. It's kept separate so it can be reused for different stages of a project snapshot and also between changes to the source files.
Constructors
| Constructor |
Description
|
Full Usage:
ProjectConfig(projectFileName, outputFileName, referencesOnDisk, otherOptions, ?isIncompleteTypeCheckEnvironment, ?useScriptResolutionRules, ?loadTime, ?stamp, ?projectId)
Parameters:
string
outputFileName : string option
referencesOnDisk : string seq
otherOptions : string seq
?isIncompleteTypeCheckEnvironment : bool
?useScriptResolutionRules : bool
?loadTime : DateTime
?stamp : int64
?projectId : string
Returns: ProjectConfig
|
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
F# Compiler Guide