FSharpWorkspaceFiles Type
Interface for managing files in an F# workspace.
Instance members
| Instance member |
Description
|
|
Indicates that a file has been closed. Any changes that were not saved to disk are undone and any further reading of the file's contents will be from the filesystem.
|
Full Usage:
this.OfProject
Parameters:
FSharpProjectIdentifier
Returns: string seq
|
Returns file paths for all source files of the given project.
|
F# Compiler Guide