CompilerEnvironment Type
Information about the compilation environment
Static members
| Static member |
Description
|
Full Usage:
CompilerEnvironment.GetConditionalDefinesForEditing(parsingOptions)
Parameters:
FSharpParsingOptions
Returns: string list
|
Return the compilation defines that should be used when editing the given file.
|
|
Return the language ID, which is the expression evaluator id that the debugger will use.
|
|
|
|
|
|
|
|
F# Compiler Guide