IDependencyManagerProvider Type
Wraps access to a DependencyManager implementation
Instance members
| Instance member |
Description
|
Full Usage:
this.ClearResultsCache
Modifiers: abstract |
Clear the results cache |
|
The help messages for this dependency manager instance
|
Key that identifies the types of dependencies that this DependencyManager operates on
E.g
nuget: indicates that this DM is for nuget packages
paket: indicates that this DM is for paket scripts, which manage nuget packages, github source dependencies etc ...
|
|
Name of the dependency manager
|
|
Resolve the dependencies, for the given set of arguments, go find the .dll references, scripts and additional include values.
|
F# Compiler Guide