IResolveDependenciesResult Type
The results of ResolveDependencies
Instance members
| Instance member |
Description
|
|
|
|
The roots to package directories
This points to the root of each located package.
The layout of the package manager will be package manager specific.
however, the dependency manager dll understands the nuget package layout
and so if the package contains folders similar to the nuget layout then
the dependency manager will be able to probe and resolve any native dependencies
required by the nuget package.
This path is also equivalent to
#I @"c:\somepath\to\packages\1.1.1\ResolvedPackage"
|
|
|
|
The resolution error log (process stderr)
|
|
The resolution output log
|
|
Succeeded?
|
F# Compiler Guide