DiagnosticContextInfo Type
Information about the context of a type equation in type-mismatch-like diagnostic
Union cases
| Union case |
Description
|
Full Usage:
CollectionElement
|
The type equation comes from a list or array constructor |
Full Usage:
DowncastUsedInsteadOfUpcast
|
The type equation comes from a downcast where an upcast could be used |
Full Usage:
ElseBranchResult
|
The type equation comes from a type check of the result of an else branch |
Full Usage:
FollowingPatternMatchClause
|
The type equation comes from the return type of a pattern match clause (not the first clause) |
Full Usage:
IfExpression
|
The type equation comes from an IF expression |
Full Usage:
NoContext
|
No context was given |
Full Usage:
OmittedElseBranch
|
The type equation comes from an omitted else branch |
Full Usage:
PatternMatchGuard
|
The type equation comes from a pattern match guard |
Full Usage:
RecordFields
|
The type equation comes from the verification of record fields |
Full Usage:
ReturnInComputationExpression
|
The type equation comes from a return in a computation expression |
Full Usage:
RuntimeTypeTest
|
The type equation comes from a runtime type test |
Full Usage:
SequenceExpression
|
The type equation comes from a sequence expression |
Full Usage:
TupleInRecordFields
|
The type equation comes from the verification of a tuple in record fields |
Full Usage:
YieldInComputationExpression
|
The type equation comes from a yield in a computation expression |
F# Compiler Guide