InsertionContextEntity Type
Helper data structure representing a symbol, suitable for implementing unresolved identifiers resolution code fixes.
Record fields
| Record Field |
Description
|
|
Full display name (i.e. last ident plus modules with `RequireQualifiedAccess` attribute prefixed).
|
|
Full name, relative to the current scope.
|
|
Last part of the entity's full name.
|
Ident parts needed to append to the current ident to make it resolvable in current scope.
|
F# Compiler Guide