obj
IStructuralEquatable
Data for use in finding unnecessarily-qualified names and generating diagnostics to simplify them
Range
range
The range of a name that can be simplified
RelativeName
string
The relative name that can be applied to a simplifiable name
Type something to start searching.