CompilerInputStream Type
Defines a read-only input stream used to feed content to the hosted F# Interactive dynamic compiler.
Constructors
| Constructor |
Description
|
|
|
Defines a read-only input stream used to feed content to the hosted F# Interactive dynamic compiler.
| Constructor |
Description
|
|
|