CompilerOutputStream Type
Defines a write-only stream used to capture output of the hosted F# Interactive dynamic compiler.
Constructors
| Constructor |
Description
|
|
|
Defines a write-only stream used to capture output of the hosted F# Interactive dynamic compiler.
| Constructor |
Description
|
|
|