IEventLoop Type
An event loop used by the currently executing F# Interactive session to execute code in the context of a GUI or another event-based system.
Instance members
| Instance member |
Description
|
Full Usage:
this.Invoke
Parameters:
unit -> 'T
Returns: 'T
The result of the operation.
Modifiers: abstract Type parameters: 'T |
Request that the given operation be run synchronously on the event loop.
|
Run the event loop.
|
|
Full Usage:
this.ScheduleRestart
Modifiers: abstract |
Schedule a restart for the event loop. |
F# Compiler Guide