IFileSystem Type
Represents a shim for the file system
Instance members
| Instance member |
Description
|
|
|
|
|
|
|
|
|
|
A shim over Directory.Delete
|
|
|
|
|
|
|
|
A shim over File.Delete
|
|
|
|
|
|
|
|
Take in a directory, filename, and return canonicalized path to the file name in directory. If file name path is rooted, ignores directory and returns file name path. Otherwise, combines directory with file name and gets full path via GetFullPathShim(string).
|
|
|
|
|
|
A shim over Path.GetTempPath
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
this.OpenFileForWriteShim
Parameters:
string
?fileMode : FileMode
?fileAccess : FileAccess
?fileShare : FileShare
Returns: Stream
Modifiers: abstract |
Open the file for writing. Returns a Stream.
|
F# Compiler Guide