FSharpActivePatternGroup Type
Represents all cases within an active pattern
Instance members
| Instance member |
Description
|
|
Try to get the entity in which the active pattern is declared
|
|
Indicate this is a total active pattern
|
|
|
|
Get the type indicating signature of the active pattern
|
F# Compiler Guide