FSharpAnonRecordTypeDetails Type
A subtype of FSharpSymbol that represents a record or union case field as seen by the F# language
Instance members
| Instance member |
Description
|
|
The assembly where the compiled form of the anonymous type is defined
|
|
The name of the compiled form of the anonymous type
|
|
|
|
The sorted labels of the anonymous type
|
F# Compiler Guide