FSharpEntity Type
A subtype of FSharpSymbol that represents a type definition or module as seen by the F# language
Instance members
| Instance member |
Description
|
|
Get the type abbreviated by an F# type abbreviation
|
|
Get the path used to address the entity (e.g. "Namespace.Module1.NestedModule2"). Gives "global" for items not in a namespace.
|
|
Get all active pattern cases defined in all active patterns in the module.
|
|
|
|
Get all the interface implementations, by walking the type hierarchy
|
Full Usage:
this.ArrayRank
Returns: int
|
Get the rank of an array type
|
|
Instantiates FSharpType
|
|
Get the base type, if any
|
|
|
|
Get the compiled name of the type or module, possibly with `n mangling. This is identical to LogicalName unless the CompiledName attribute is used.
|
|
Get the declaration location for the type constructor
|
|
Get the declared interface implementations
|
|
Get the enclosing entity for the definition
|
|
Get the name of the type or module as displayed in F# code
|
|
Indicates if the type is a delegate with the given Invoke signature
|
|
Get the fields of a record, class, struct or enum from the perspective of the F# language. This includes static fields, the 'val' bindings in classes and structs, and the value definitions in enums. For classes, the list may include compiler generated fields implied by the use of primary constructors.
|
|
Get the full name of the type or module
|
|
Get the generic parameters, possibly including unit-of-measure parameters
|
|
Get the generic parameters, possibly including unit-of-measure parameters
|
|
Public nested entities (methods, functions, values, nested modules).
|
|
Indicates if the type is implemented through a mapping to IL assembly code. This is only true for types in FSharp.Core.dll
|
|
Indicates that a module is compiled to a class with the given mangled name. The mangling is reversed during lookup
|
|
Indicates if the entity is an abstract class
|
|
Indicates if the entity is an array type
|
|
Check if the entity inherits from System.Attribute in its type hierarchy
|
|
Indicates if is the 'byref<_>' type definition used for byref types in F#-compiled assemblies
|
|
Indicates if the entity is a class type definition
|
|
Indicates if the entity is a delegate type definition
|
|
Indicates if the entity is an enum type definition
|
|
Indicates if this is a reference to something in an F#-compiled assembly
|
|
Indicates if the entity is a measure, type or exception abbreviation
|
|
Indicates an F# exception declaration
|
|
Indicates if the entity is an F# module definition
|
|
Indicates if the entity is record type
|
|
Indicates if the entity is union type
|
|
Indicates if the entity is an interface type definition
|
|
Indicates if the entity is a measure definition
|
|
Indicates if the entity is a part of a namespace path
|
|
Indicates if the entity is a type definition for a reference type where the implementation details are hidden by a signature
|
|
Indicates if the entity is a provided type
|
|
Indicates if the entity is an erased provided type
|
|
Indicates if the entity is a generated provided type
|
|
Indicates if the entity is a 'fake' symbol related to a static instantiation of a type provider
|
|
Indicates if the entity is in an unresolved assembly
|
|
Indicates if the entity is a struct or enum
|
|
Get the name of the type or module, possibly with `n mangling
|
|
Get the properties, events and methods of a type definitions, or the functions and values of a module
|
|
|
|
Get the modules and types defined in a module, or the nested types of a type
|
|
|
|
Get the declared accessibility of the representation, not taking signatures into account
|
|
Get the static parameters for a provided type
|
|
|
|
|
|
|
|
|
|
Safe version of `GetMembersFunctionsAndValues`.
|
|
Get the source text of the entity's signature to be used as metadata.
|
|
Get the cases of a union type
|
|
Indicates if the type prefers the "tycon" syntax for display etc.
|
|
Get the XML documentation for the entity
|
|
Get the XML documentation signature for the entity, used for .xml file lookup for compiled code
|
Inherited members
Inherited from
FSharpSymbol
Instance members
| Instance member |
Description
|
Full Usage:
this.GetEffectivelySameAsHash
Returns: int
|
A hash compatible with the IsEffectivelySameAs relation
|
|
Indicates if this symbol has an attribute matching the full name of the given type parameter
|
|
Computes if the symbol is accessible for the given accessibility rights
|
|
Return true if two symbols are effectively the same when referred to in F# source code text. This sees through signatures (a symbol in a signature will be considered effectively the same as the matching symbol in an implementation). In addition, other equivalences are applied when the same F# source text implies the same declaration name - for example, constructors are considered to be effectively the same symbol as the corresponding type definition. This is the relation used by GetUsesOfSymbol and GetUsesOfSymbolInFile.
|
|
Try to get an attribute matching the full name of the given type parameter
|
|
Gets the display name for the symbol. Double backticks are added if the name is not a valid identifier. For FSharpParameter symbols without a name for the parameter, this returns "````"
|
Full Usage:
this.ObsoleteDiagnosticInfo
Returns: FSharpObsoleteDiagnosticInfo option
Modifiers: abstract |
|
|
|
|
Get the assembly declaring this symbol
|
|
Get the attributes for the symbol, if any
|
|
|
|
|
|
Get a textual representation of the full name of the symbol. The text returned for some symbols may not be a valid identifier path in F# code, but rather a human-readable representation of the symbol.
|
|
Gets the display name for the symbol where double backticks are not added for non-identifiers
|
|
|
|
Get the declared accessibility of the symbol, if any
|
F# Compiler Guide