Logo F# Compiler Guide

FSharpParameter Type

A subtype of FSharpSymbol that represents a parameter

Instance members

Instance member Description

this.DeclarationLocation

Full Usage: this.DeclarationLocation

Returns: range

The declaration location of the parameter

Returns: range

this.IsInArg

Full Usage: this.IsInArg

Returns: bool

Indicate this is an in argument

Returns: bool

this.IsOptionalArg

Full Usage: this.IsOptionalArg

Returns: bool

Indicate this is an optional argument

Returns: bool

this.IsOutArg

Full Usage: this.IsOutArg

Returns: bool

Indicate this is an out argument

Returns: bool

this.IsParamArrayArg

Full Usage: this.IsParamArrayArg

Returns: bool

Indicate this is a param array argument

Returns: bool

this.Name

Full Usage: this.Name

Returns: string option

The optional name of the parameter

Returns: string option

this.Type

Full Usage: this.Type

Returns: FSharpType

The declared or inferred type of the parameter

Returns: FSharpType

Inherited members

Inherited from FSharpSymbol

Instance members

Instance member Description

this.GetEffectivelySameAsHash

Full Usage: this.GetEffectivelySameAsHash

Returns: int

A hash compatible with the IsEffectivelySameAs relation

Returns: int

this.HasAttribute

Full Usage: this.HasAttribute

Returns: bool
Type parameters: 'T

Indicates if this symbol has an attribute matching the full name of the given type parameter

Returns: bool

this.IsAccessible

Full Usage: this.IsAccessible

Parameters:
Returns: bool

Computes if the symbol is accessible for the given accessibility rights

arg0 : FSharpAccessibilityRights
Returns: bool

this.IsEffectivelySameAs

Full Usage: this.IsEffectivelySameAs

Parameters:
Returns: bool

Return true if two symbols are effectively the same when referred to in F# source code text. This sees through signatures (a symbol in a signature will be considered effectively the same as the matching symbol in an implementation). In addition, other equivalences are applied when the same F# source text implies the same declaration name - for example, constructors are considered to be effectively the same symbol as the corresponding type definition. This is the relation used by GetUsesOfSymbol and GetUsesOfSymbolInFile.

other : FSharpSymbol
Returns: bool

this.TryGetAttribute

Full Usage: this.TryGetAttribute

Returns: FSharpAttribute option
Type parameters: 'T

Try to get an attribute matching the full name of the given type parameter

Returns: FSharpAttribute option

this.ImplementationLocation

Full Usage: this.ImplementationLocation

Returns: range option

Get the implementation location for the symbol if it was declared in a signature that has an implementation

Returns: range option

this.DisplayNameCore

Full Usage: this.DisplayNameCore

Returns: string

Gets the display name for the symbol where double backticks are not added for non-identifiers

Returns: string

this.IsExplicitlySuppressed

Full Usage: this.IsExplicitlySuppressed

Returns: bool
Returns: bool

this.DisplayName

Full Usage: this.DisplayName

Returns: string

Gets the display name for the symbol. Double backticks are added if the name is not a valid identifier. For FSharpParameter symbols without a name for the parameter, this returns "````"

Returns: string

this.SignatureLocation

Full Usage: this.SignatureLocation

Returns: range option

Get the signature location for the symbol if it was declared in an implementation

Returns: range option

this.Accessibility

Full Usage: this.Accessibility

Returns: FSharpAccessibility
Modifiers: abstract

Get the declared accessibility of the symbol, if any

Returns: FSharpAccessibility

this.DeclarationLocation

Full Usage: this.DeclarationLocation

Returns: range option

Get the declaration location for the symbol

Returns: range option

this.Assembly

Full Usage: this.Assembly

Returns: FSharpAssembly

Get the assembly declaring this symbol

Returns: FSharpAssembly

this.Attributes

Full Usage: this.Attributes

Returns: IList<FSharpAttribute>
Modifiers: abstract

Get the attributes for the symbol, if any

Returns: IList<FSharpAttribute>

this.FullName

Full Usage: this.FullName

Returns: string

Get a textual representation of the full name of the symbol. The text returned for some symbols may not be a valid identifier path in F# code, but rather a human-readable representation of the symbol.

Returns: string

Type something to start searching.