ParsedInput Type
Represents the syntax tree for a parsed implementation or signature file
Union cases
| Union case |
Description
|
|
A parsed implementation file
|
|
A parsed signature file
|
Instance members
| Instance member |
Description
|
|
Gets the file name for the parsed input
|
|
|
|
Gets the qualified name used to help match signature and implementation files
|
|
Gets the syntax range of this construct
|
F# Compiler Guide