SynConst Type
The unchecked abstract syntax tree of constants in F# types and expressions.
Union cases
| Union case |
Description
|
F# syntax: true, false
|
|
F# syntax: 13uy, 0x40uy, 0oFFuy, 0b0111101uy
|
|
Full Usage:
Bytes(bytes, synByteStringKind, range)
Parameters:
byte[]
synByteStringKind : SynByteStringKind
range : range
|
F# syntax: verbatim or regular byte string, e.g. "abc"B. Also used internally in the typechecker once an array of unit16 constants is detected, to allow more efficient processing of large arrays of uint16 constants.
|
F# syntax: 'a'
|
|
|
F# syntax: 23.4M
|
|
F# syntax: 1.30, 1.40e10 etc.
|
|
F# syntax: 13s, 0x4000s, 0o0777s, 0b0111101s
|
|
F# syntax: 13, 0x4000, 0o0777
|
|
F# syntax: 13L
|
|
F# syntax: 13n
|
Full Usage:
Measure(constant, constantRange, synMeasure, trivia)
Parameters:
SynConst
constantRange : range
synMeasure : SynMeasure
trivia : SynMeasureConstantTrivia
|
Old comment: "we never iterate, so the const here is not another SynConst.Measure"
|
|
F# syntax: 13y, 0xFFy, 0o077y, 0b0111101y
|
|
F# syntax: 1.30f, 1.40e10f etc.
|
|
|
Full Usage:
String(text, synStringKind, range)
Parameters:
string
synStringKind : SynStringKind
range : range
|
F# syntax: verbatim or regular string, e.g. "abc"
|
|
F# syntax: 13us, 0x4000us, 0o0777us, 0b0111101us
|
|
Used internally in the typechecker once an array of unit16 constants is detected, to allow more efficient processing of large arrays of uint16 constants.
|
|
F# syntax: 13u, 0x4000u, 0o0777u
|
|
F# syntax: 13UL
|
|
F# syntax: 13un
|
Full Usage:
Unit
|
F# syntax: () |
|
Instance members
| Instance member |
Description
|
|
F# Compiler Guide