SynLetOrUse Type
Represents a 'let' or 'use' expression with its bindings and body
Record fields
| Record Field |
Description
|
|
The bindings in this let/use expression
|
The body expression
|
|
|
true if the binding was explicitly written by the user in the source code, false if generated by the compiler
|
|
true for 'let rec' and 'use rec' bindings, false for 'let' and 'use' bindings
|
The syntax range of this expression
|
|
|
Trivia for this expression
|
F# Compiler Guide