FSharpDiagnostic Type
Represents a diagnostic produced by the F# compiler
Instance members
| Instance member |
Description
|
|
Gets the original severity prior to adjustments via compiler flags, #nowarn and other features
|
Gets the end position for the diagnostic
|
|
Full Usage:
this.EndColumn
Returns: int
|
Gets the end column for the diagnostic
|
Full Usage:
this.EndLine
Returns: int
|
Gets the end line for the diagnostic
|
Full Usage:
this.ErrorNumber
Returns: int
|
Gets the number for the diagnostic
|
|
Gets the number prefix for the diagnostic, usually "FS" but may differ for analyzers
|
|
Gets the full error number text e.g "FS0031"
|
|
Gets the contextually relevant data to each particular diagnostic for things like code fixes
|
|
Gets the file name for the diagnostic
|
|
Gets the message for the diagnostic
|
|
Gets the range for the diagnostic
|
|
Gets the message for the diagnostic as parts classified by their kind, e.g. so that tooling is able to render it with colors. Message is the text of all parts concatenated.
|
|
Gets the severity for the diagnostic
|
|
Gets the start position for the diagnostic
|
Full Usage:
this.StartColumn
Returns: int
|
Gets the start column for the diagnostic
|
Full Usage:
this.StartLine
Returns: int
|
Gets the start line for the diagnostic
|
|
Gets the subcategory for the diagnostic
|
Static members
| Static member |
Description
|
Full Usage:
FSharpDiagnostic.Create(severity, message, number, range, ?numberPrefix, ?subcategory)
Parameters:
FSharpDiagnosticSeverity
message : RichText
number : int
range : range
?numberPrefix : string
?subcategory : string
Returns: FSharpDiagnostic
|
Creates a diagnostic whose message parts are classified by their kind, e.g. so that tooling is able to render it with colors
|
Full Usage:
FSharpDiagnostic.Create(severity, message, number, range, ?numberPrefix, ?subcategory)
Parameters:
FSharpDiagnosticSeverity
message : string
number : int
range : range
?numberPrefix : string
?subcategory : string
Returns: FSharpDiagnostic
|
Creates a diagnostic, e.g. for reporting from an analyzer
|
|
|
|
F# Compiler Guide