InteractiveSettings Type
Operations supported by the currently executing F# Interactive session.
Instance members
| Instance member |
Description
|
Full Usage:
this.AddPrintTransformer
Parameters:
'T -> objnull
Type parameters: 'T |
Register a print transformer that controls the output of the interactive session.
|
Full Usage:
this.AddPrinter
Parameters:
'T -> string
Type parameters: 'T |
Register a printer that controls the output of the interactive session.
|
Full Usage:
this.CommandLineArgs
Returns: string[]
|
The command line arguments after ignoring the arguments relevant to the interactive environment and replacing the first argument with the name of the last script file, if any. Thus 'fsi.exe test1.fs test2.fs -- hello goodbye' will give arguments 'test2.fs', 'hello', 'goodbye'. This value will normally be different to those returned by System.Environment.GetCommandLineArgs.
|
|
Gets or sets the current event loop being used to process interactions.
|
Full Usage:
this.FloatingPointFormat
Returns: string
|
Get or set the floating point format used in the output of the interactive session.
|
|
Get or set the format provider used in the output of the interactive session.
|
Full Usage:
this.PrintDepth
Returns: int
|
Get or set the print depth of the interactive session.
|
Full Usage:
this.PrintLength
Returns: int
|
Get or set the total print length of the interactive session.
|
Full Usage:
this.PrintSize
Returns: int
|
Get or set the total print size of the interactive session.
|
Full Usage:
this.PrintWidth
Returns: int
|
Get or set the print width of the interactive session.
|
Full Usage:
this.ShowDeclarationValues
Returns: bool
|
When set to 'false', disables the display of declaration values in the output of the interactive session.
|
Full Usage:
this.ShowIEnumerable
Returns: bool
|
When set to 'false', disables the display of sequences in the output of the interactive session.
|
Full Usage:
this.ShowProperties
Returns: bool
|
When set to 'false', disables the display of properties of evaluated objects in the output of the interactive session.
|
F# Compiler Guide