FSharpField Type
A subtype of FSharpSymbol that represents a record or union case field as seen by the F# language
Instance members
| Instance member |
Description
|
|
If the field is from an anonymous record type then get the details of the field including the index in the sorted array of fields
|
|
Get the declaration location of the field
|
|
Get the declaring entity of this field, if any. Fields from anonymous types do not have a declaring entity
|
|
Returns the declaring union case symbol
|
|
Get the attributes attached to generated field
|
|
Get the type of the field, w.r.t. the generic parameters of the enclosing type constructor
|
Full Usage:
this.IsAnonRecordField
Returns: bool
|
Is this a field from an anonymous record type?
|
Full Usage:
this.IsCompilerGenerated
Returns: bool
|
Indicates a compiler generated field, not visible to Intellisense or name resolution
|
Full Usage:
this.IsDefaultValue
Returns: bool
|
Indicates if the field declared is declared 'DefaultValue'
|
Full Usage:
this.IsLiteral
Returns: bool
|
Indicates if the field has a literal value
|
Full Usage:
this.IsMutable
Returns: bool
|
Indicates if the field is declared 'static'
|
Full Usage:
this.IsNameGenerated
Returns: bool
|
Indicates if the field name was generated by compiler (e.g. ItemN names in union cases and DataN in exceptions). This API returns true for source defined symbols only.
|
Full Usage:
this.IsStatic
Returns: bool
|
Indicates a static field
|
Full Usage:
this.IsUnionCaseField
Returns: bool
|
Indicates if the field is declared in a union case
|
Full Usage:
this.IsUnresolved
Returns: bool
|
Indicates if the record field is for a type in an unresolved assembly
|
Full Usage:
this.IsVolatile
Returns: bool
|
Indicates if the field is declared volatile
|
Full Usage:
this.LiteralValue
Returns: objnull option
|
Get the default initialization info, for static literals
|
Full Usage:
this.Name
Returns: string
|
Get the name of the field
|
|
Get the attributes attached to generated property
|
|
Get the XML documentation for the entity
|
Full Usage:
this.XmlDocSig
Returns: string
|
Get the XML documentation signature for .xml file lookup for the field, used for .xml file lookup for compiled code
|
Inherited members
Inherited from
FSharpSymbol
Instance members
| Instance member |
Description
|
Full Usage:
this.GetEffectivelySameAsHash
Returns: int
|
A hash compatible with the IsEffectivelySameAs relation
|
Full Usage:
this.HasAttribute
Returns: bool
Type parameters: 'T |
Indicates if this symbol has an attribute matching the full name of the given type parameter
|
|
Computes if the symbol is accessible for the given accessibility rights
|
|
Return true if two symbols are effectively the same when referred to in F# source code text. This sees through signatures (a symbol in a signature will be considered effectively the same as the matching symbol in an implementation). In addition, other equivalences are applied when the same F# source text implies the same declaration name - for example, constructors are considered to be effectively the same symbol as the corresponding type definition. This is the relation used by GetUsesOfSymbol and GetUsesOfSymbolInFile.
|
|
Try to get an attribute matching the full name of the given type parameter
|
|
Get the declaration location for the symbol
|
|
Get the signature location for the symbol if it was declared in an implementation
|
Full Usage:
this.IsExplicitlySuppressed
Returns: bool
|
|
|
Get the declared accessibility of the symbol, if any
|
|
Get the assembly declaring this symbol
|
|
Get the implementation location for the symbol if it was declared in a signature that has an implementation
|
|
Get the attributes for the symbol, if any
|
Full Usage:
this.FullName
Returns: string
|
Get a textual representation of the full name of the symbol. The text returned for some symbols may not be a valid identifier path in F# code, but rather a human-readable representation of the symbol.
|
Full Usage:
this.DisplayNameCore
Returns: string
|
Gets the display name for the symbol where double backticks are not added for non-identifiers
|
Full Usage:
this.DisplayName
Returns: string
|
Gets the display name for the symbol. Double backticks are added if the name is not a valid identifier. For FSharpParameter symbols without a name for the parameter, this returns "````"
|
F# Compiler Guide